/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_RTCConfigurationBinding_h__
#define mozilla_dom_RTCConfigurationBinding_h__

#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/DOMJSClass.h"
#include "mozilla/dom/DOMJSProxyHandler.h"

namespace mozilla {
namespace dom {

struct RTCIceServer : public MainThreadDictionaryBase {
  RTCIceServer() {}
  bool Init(JSContext* cx, JS::Handle<JS::Value> val);
  bool Init(const nsAString& aJSON);
  bool ToObject(JSContext* cx, JS::Handle<JSObject*> parentObject, JS::Value *vp) const;
  void TraceDictionary(JSTracer* trc);

  nsString mCredential;
  Optional<nsString > mUrl;
  nsString mUsername;
private:
  // Disallow copy-construction
  RTCIceServer(const RTCIceServer&) MOZ_DELETE;
  static bool InitIds(JSContext* cx);
  static bool initedIds;
  static jsid credential_id;
  static jsid url_id;
  static jsid username_id;
};
struct RTCIceServerInitializer : public RTCIceServer {
  RTCIceServerInitializer() {
    // Safe to pass a null context if we pass a null value
    Init(nullptr, JS::NullHandleValue);
  }
};

struct RTCConfiguration : public MainThreadDictionaryBase {
  RTCConfiguration() {}
  bool Init(JSContext* cx, JS::Handle<JS::Value> val);
  bool Init(const nsAString& aJSON);
  bool ToObject(JSContext* cx, JS::Handle<JSObject*> parentObject, JS::Value *vp) const;
  void TraceDictionary(JSTracer* trc);

  Optional<Sequence<RTCIceServer > > mIceServers;
private:
  // Disallow copy-construction
  RTCConfiguration(const RTCConfiguration&) MOZ_DELETE;
  static bool InitIds(JSContext* cx);
  static bool initedIds;
  static jsid iceServers_id;
};
struct RTCConfigurationInitializer : public RTCConfiguration {
  RTCConfigurationInitializer() {
    // Safe to pass a null context if we pass a null value
    Init(nullptr, JS::NullHandleValue);
  }
};

} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_RTCConfigurationBinding_h__
