/* -*- Mode: C++; tab-width: 40; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this file,
 * You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "nsISupports.idl"

[scriptable, uuid(2e61eed1-5983-4562-8f26-fd361ab4a00d)]
interface nsIDOMMozWakeLock : nsISupports
{
    readonly attribute DOMString topic;

    /**
     * Release the wake lock.
     *
     * @throw NS_ERROR_DOM_INVALID_STATE_ERR if already unlocked.
     */
    void unlock();
};
