/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_FileBinding_h__
#define mozilla_dom_FileBinding_h__

#include "BlobBinding.h"
#include "mozilla/ErrorResult.h"
#include "mozilla/dom/BindingDeclarations.h"
#include "mozilla/dom/DOMJSClass.h"
#include "mozilla/dom/DOMJSProxyHandler.h"

namespace mozilla {
namespace dom {

struct FilePropertyBag : public BlobPropertyBag {
  FilePropertyBag() {}
  bool Init(JSContext* cx, JS::Handle<JS::Value> val);
  bool Init(const nsAString& aJSON);
  bool ToObject(JSContext* cx, JS::Handle<JSObject*> parentObject, JS::Value *vp) const;
  void TraceDictionary(JSTracer* trc);

  nsString mName;
private:
  // Disallow copy-construction
  FilePropertyBag(const FilePropertyBag&) MOZ_DELETE;
  static bool InitIds(JSContext* cx);
  static bool initedIds;
  static jsid name_id;
};
struct FilePropertyBagInitializer : public FilePropertyBag {
  FilePropertyBagInitializer() {
    // Safe to pass a null context if we pass a null value
    Init(nullptr, JS::NullHandleValue);
  }
};

} // namespace dom
} // namespace mozilla

#endif // mozilla_dom_FileBinding_h__
